@@ -36,7 +36,7 @@ repository.
 
 =item B<-R>, B<--release-use-changelog>
 
-When used in conjunction with --release, if there are uncommited
+When used in conjunction with B<--release>, if there are uncommited
 changes to the changelog then derive the commit message from those
 changes rather than using the default message.
 
@@ -108,17 +108,17 @@ ignored for this purpose.  The currently recognised variables are:
 
 =item B<DEBCOMMIT_STRIP_MESSAGE>
 
-If this is set to I<no>, then it is the same as the --no-strip-message
+If this is set to I<no>, then it is the same as the B<--no-strip-message>
 command line parameter being used. The default is I<yes>.
 
 =item B<DEBCOMMIT_SIGN_TAGS>
 
-If this is set to I<yes>, then it is the same as the --sign-tags command
+If this is set to I<yes>, then it is the same as the B<--sign-tags> command
 line parameter being used. The default is I<no>.
 
 =item B<DEBCOMMIT_RELEASE_USE_CHANGELOG>
 
-If this is set to I<yes>, then it is the same as the --release-use-changelog
+If this is set to I<yes>, then it is the same as the B<--release-use-changelog>
 command line parameter being used. The default is I<no>.
 
 =item B<DEBSIGN_KEYID>
@@ -148,7 +148,7 @@ has been automatically determined from the changelog.
 =item B<git>
 
 If only a single change is detected in the changelog, B<debcommit> will unfold
-it to a single line and behave as if --strip-message was used.
+it to a single line and behave as if B<--strip-message> was used.
 
 Otherwise, the first change will be unfolded and stripped to form a summary line
 and a commit message formed using the summary line followed by a blank line and
@@ -163,7 +163,7 @@ allow the message to be fine-tuned.
 
 =item B<bzr>
 
-If the changelog entry used for the commit message closes any bugs then --fixes
+If the changelog entry used for the commit message closes any bugs then B<--fixes>
 options to "bzr commit" will be generated to associate the revision and the bugs.
 
 =back
@@ -244,7 +244,7 @@ my $signtags=0;
 my $changelog;
 my $changelog_info=0;
 my $keyid;
-my ($version, $date, $maintainer);
+my ($package, $version, $date, $maintainer);
 my $onlydebian=0;
 
 # Now start by reading configuration files and then command line
@@ -359,9 +359,10 @@ if ($release || $changelog_info) {
 	if ($log->{Distribution} =~ /UNRELEASED/) {
 	    die "debcommit: $changelog says it's UNRELEASED\nTry running dch --release first\n";
 	}
+	$package = $log->{Source};
 	$version = $log->{Version};
 
-	$message="releasing version $version" if ! defined $message;
+	$message="releasing package $package version $version" if ! defined $message;
     }
     if ($changelog_info) {
 	$maintainer = $log->{Maintainer};
@@ -377,7 +378,7 @@ if ($edit) {
 
 if (not $confirm or confirm($message)) {
     commit($message);
-    tag($version) if $release;
+    tag($package, $version) if $release;
 }
 
 # End of code, only subs below
@@ -518,8 +519,8 @@ sub commit {
 	if (! @files_to_commit && ($all || $release)) {
 	    # check to see if the WC is clean. git-commit would exit
 	    # nonzero, so don't run it in --all or --release mode.
-	    my $status=`LANG=C git status`;
-	    if ($status=~/nothing to commit \(working directory clean\)/) {
+	    my $status=`git status --porcelain`;
+	    if (!$status) {
 		    print $status;
 		    return;
 	    }
@@ -601,7 +602,7 @@ sub commit {
 }
 
 sub tag {
-    my $tag=shift;
+    my ($package, $tag) = @_;
 
     if ($prog eq 'svn' || $prog eq 'svk') {
 	my $svnpath=`svnpath`;
@@ -610,11 +611,11 @@ sub tag {
 	chomp $tagpath;
 
 	if (! action($prog, "copy", $svnpath, "$tagpath/$tag",
-		     "-m", "tagging version $tag")) {
+		     "-m", "tagging package $package version $tag")) {
 	    if (! action($prog, "mkdir", $tagpath,
 			 "-m", "create tag directory") ||
 		! action($prog, "copy", $svnpath, "$tagpath/$tag",
-			 "-m", "tagging version $tag")) {
+			 "-m", "tagging package $package version $tag")) {
 		die "debcommit: failed tagging with $tag\n";
 	    }
 	}
@@ -663,13 +664,13 @@ sub tag {
 	if ($signtags) {
 		if (defined $keyid) {
 			if (! action($prog, "tag", "-u", $keyid, "-m",
-			             "tagging version $tag", $tag)) {
+			             "tagging package $package version $tag", $tag)) {
 	        		die "debcommit: failed tagging with $tag\n";
 			}
 		}
 		else {
 			if (! action($prog, "tag", "-s", "-m",
-			             "tagging version $tag", $tag)) {
+			             "tagging package $package version $tag", $tag)) {
 	        		die "debcommit: failed tagging with $tag\n";
 			}
 		}
@@ -681,7 +682,7 @@ sub tag {
     elsif ($prog eq 'hg') {
 	$tag=~s/^[0-9]+://; # strip epoch
 	$tag="debian-$tag";
-    	if (! action($prog, "tag", "-m", "tagging version $tag", $tag)) {
+	if (! action($prog, "tag", "-m", "tagging package $package version $tag", $tag)) {
 	        die "debcommit: failed tagging with $tag\n";
     	}
     }
